@@ -1,5 +1,3 @@
-# fmt: off
-
 import logging
 import os
 import signal
@@ -10,19 +8,26 @@ from datetime import datetime, timedelta, timezone
 from operator import itemgetter
 from pathlib import Path
 from typing import (
-    Any, Callable, Dict, Iterable, Iterator,
-    List, Optional, TextIO, Tuple, Union
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    TextIO,
+    Tuple,
+    Union,
 )
 
-import pandas as pd
 import pyModeS as pms
 from tqdm.autonotebook import tqdm
 
+import pandas as pd
+
 from ...core import Flight, Traffic
 from ...data.basic.airports import Airport
 
-# fmt: on
-
 
 def next_msg(chunk_it: Iterator[bytes]) -> Iterator[bytes]:
     data = b""
@@ -289,7 +294,7 @@ class Aircraft(object):
     @altcode.setter
     def altcode(self, args):
         t, msg = args
-        from pyModeS.c_common import hex2bin
+        from pyModeS import hex2bin
 
         if set(hex2bin(msg)[19:32]) in [{"0"}, {"1"}]:
             return
@@ -306,14 +311,18 @@ class Aircraft(object):
     @idcode.setter
     def idcode(self, args):
         t, msg = args
-        from pyModeS.c_common import hex2bin
+        from pyModeS import hex2bin
 
         if set(hex2bin(msg)[19:32]) in [{"0"}, {"1"}]:
             return
         idcode = pms.common.idcode(msg)
         with self.lock:
             self.cumul.append(
-                dict(timestamp=t, icao24=self.icao24, squawk=idcode,)
+                dict(
+                    timestamp=t,
+                    icao24=self.icao24,
+                    squawk=idcode,
+                )
             )
 
     @property
@@ -782,7 +791,7 @@ class Decoder:
         elif isinstance(reference, Airport):
             lat0, lon0 = reference.latlon
         else:
-            lat0, lon0 = reference
+            lat0, lon0 = reference  # type: ignore
 
         self.acs: AircraftDict = AircraftDict()
         self.acs.set_latlon(lat0, lon0)
