@@ -1,13 +1,10 @@
 from datetime import datetime, timedelta, timezone
 from pathlib import Path
-from typing import Optional, Set, Tuple, Union
+from typing import TYPE_CHECKING, Optional, Set, Tuple, Union
+
+from requests import Session
 
 import pandas as pd
-from cartopy.crs import PlateCarree
-from cartopy.mpl.geoaxes import GeoAxesSubplot
-from matplotlib.artist import Artist
-from matplotlib.patches import Polygon as MplPolygon
-from requests import Session
 from shapely.geometry import Polygon
 from shapely.geometry.base import BaseGeometry
 
@@ -18,6 +15,10 @@ from ...core.time import round_time, timelike, to_datetime
 from ..basic.airports import Airport
 from .opensky_impala import Impala
 
+if TYPE_CHECKING:
+    from cartopy.mpl.geoaxes import GeoAxesSubplot
+    from matplotlib.artist import Artist
+
 
 class Coverage(object):
     """Plots the output of the coverage json."""
@@ -31,9 +32,11 @@ class Coverage(object):
         ).sort_values("altitude")
 
     def plot(
-        self, ax: GeoAxesSubplot, cmap: str = "inferno", s: int = 5, **kwargs
-    ) -> Artist:
+        self, ax: "GeoAxesSubplot", cmap: str = "inferno", s: int = 5, **kwargs
+    ) -> "Artist":
         """Plotting function. All arguments are passed to ax.scatter"""
+        from cartopy.crs import PlateCarree
+
         return ax.scatter(
             self.df.longitude,
             self.df.latitude,
@@ -74,8 +77,10 @@ class SensorRange(ShapelyMixin):
             ]
             self.point.name = value[0]["serial"]
 
-    def plot(self, ax: GeoAxesSubplot, **kwargs) -> Artist:
+    def plot(self, ax: "GeoAxesSubplot", **kwargs) -> "Artist":
         """Plotting function. All arguments are passed to the geometry"""
+        from cartopy.crs import PlateCarree
+        from matplotlib.patches import Polygon as MplPolygon
 
         if "facecolor" not in kwargs:
             kwargs["facecolor"] = "None"
@@ -211,7 +216,9 @@ class OpenSky(Impala):
 
         return StateVectors(r, self)
 
-    def api_tracks(self, icao24: str, time: Optional[timelike] = None) -> Flight:
+    def api_tracks(
+        self, icao24: str, time: Optional[timelike] = None
+    ) -> Flight:
         """Returns a Flight corresponding to a given aircraft.
 
         Official documentation
@@ -247,7 +254,8 @@ class OpenSky(Impala):
         """
         time = int(to_datetime(time).timestamp()) if time is not None else 0
         c = self.session.get(
-            f"https://opensky-network.org/api/tracks/?icao24={icao24}&time={time}"
+            f"https://opensky-network.org/api/tracks/"
+            f"?icao24={icao24}&time={time}"
         )
         c.raise_for_status()
         json = c.json()
@@ -279,7 +287,7 @@ class OpenSky(Impala):
         c.raise_for_status()
         json = c.json()
 
-        return tuple(airports[a] for a in json["route"])  # type: ignore
+        return tuple(airports[a] for a in json["route"])
 
     def api_aircraft(
         self,
