@@ -88,10 +88,15 @@ class Airways(GeoDBMixin):
     def download_data(self) -> None:  # coverage: ignore
         from .. import session
 
-        c = session.get(base_url + "/earth_awy.dat")
-        c.raise_for_status()
-        b = BytesIO(c.content)
-        self._data = pd.read_csv(b, sep=" ", header=None)
+        cache_file = self.cache_dir / "earth_awy.dat"
+        if cache_file.exists():
+            self._data = pd.read_csv(cache_file, sep=" ", header=None)
+        else:
+            c = session.get(f"{base_url}/earth_awy.dat")
+            c.raise_for_status()
+            b = BytesIO(c.content)
+            self._data = pd.read_csv(b, sep=" ", header=None)
+
         self._data.columns = ["route", "id", "navaid", "latitude", "longitude"]
         self._data.to_pickle(self.cache_dir / "traffic_airways.pkl")
 
